@@ -346,7 +346,7 @@ not be enclosed in { } or ( ).")
 	     (mapcar #'symbol-name
 		     '(ifeq ifneq else endif endef include)))
 	    "\\|-include\\)[ \t\n]+")
-    1 font-lock-preprocessor-face)
+    1 'font-lock-preprocessor-face)
 
    '("^\\(ifn?def\\)[ \t]+\\(.*$\\)"
      (1 font-lock-preprocessor-face) (2 font-lock-reference-face nil t))
